@@ -2,14 +2,18 @@ from .dataset import *
 from .logistic_regression import *
 from .svm import *
 from .ksvm import *
+from .multiclass_svm import *
+from .multiclass_ksvm import *
 from .multinomial_logistic import *
 from .gda import *
 from .naivebayes import *
 from .nearest_neighbor import *
+from .kmeans import *
 from .classtree import *
 from .perceptron import *
 from .mlp import *
 from .cnn import *
 from .normalization import *
 from .pca import *
-from .pvmlnet import *
+from .rnn import *
+from .utils import *
